EasyExtend.langlets.p4d.xmlutils.xmlprinter

Package EasyExtend :: Package langlets :: Package p4d :: Module xmlutils :: Class xmlprinter |
[hide private]
[frames] | no frames]

# Class xmlprinter

           object --+
                    |
    p4dutils.pprinter --+
                        |
                       xmlprinter

Instance Methods | [hide private]
filter(self, *args, **kwd) |
pprint(self, xml_declaration=True, strip_p4d=False) |
formatAttributes(self, attr, strip_p4d, prefixed) |
Inherited from `p4dutils.pprinter`: `__init__`, `walker` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`